# Generated by roxygen2: do not edit by hand

export(DiffPropTest)
export(FracFixR)
export(PlotComparison)
export(PlotFractions)
export(get_corrected_counts)
import(dplyr)
import(ggplot2)
importFrom(RColorBrewer,brewer.pal)
importFrom(aod,betabin)
importFrom(future,plan)
importFrom(future.apply,future_lapply)
importFrom(grDevices,dev.off)
importFrom(matrixStats,rowProds)
importFrom(nnls,nnls)
importFrom(parallelly,availableCores)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,p.adjust)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(tidyr,pivot_longer)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
