% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{logit_diff_test}
\alias{logit_diff_test}
\title{logit_diff_test: Logit-based Differential Test}
\usage{
logit_diff_test(counts, successes, annotation)
}
\arguments{
\item{counts}{Total count matrix}

\item{successes}{Proportion matrix}

\item{annotation}{Sample metadata}
}
\value{
Data frame with test results for all transcripts
}
\description{
Alternative to GLM using logit transformation. Faster but potentially
less powerful than the full GLM approach.
}
\keyword{internal}
