% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fracfixr.r
\name{run_glm}
\alias{run_glm}
\title{run_glm: Binomial GLM for Single Transcript}
\usage{
run_glm(transcript, counts, successes, sample_info)
}
\arguments{
\item{transcript}{Transcript identifier}

\item{counts}{Total count matrix}

\item{successes}{Proportion matrix}

\item{sample_info}{Sample metadata with Condition factor}
}
\value{
Data frame with test results for this transcript
}
\description{
Fits a binomial generalized linear model to test for differential
proportions between conditions for a single transcript.
}
\keyword{internal}
